package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````/"````````!``````````,BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````':@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````4)@`````
M``!0F``````````0`````````0````8```"0FP```````)"K````````D*L`
M``````#`!````````.@$`````````!`````````"````!@```*B;````````
MJ*L```````"HJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```"XCP```````+B/````````N(\```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````D)L```````"0
MJP```````)"K````````<`0```````!P!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`#$8=L4Q7D4!_40S"P9JFMO+2/0!!````!`````!````1TY5```````$````
M#P`````````1````2`````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````2````$L```!.````3P```%<```!8````6@```%P`
M``!=````7@```&````!B````8P```&4``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`)`>``````````````````#N`@``$0``````````````````
M``````#5````$@````````````````````````#%`0``$@``````````````
M``````````#*`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"=`@``$@``````
M``````````````````#,`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"Y`@``$@````````````````````````#4
M`@``$0````````````````````````"D`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#X`0``$@````````````````````````#3`0``$@``````````
M``````````````#K`0``$@````````````````````````"^`0``$@``````
M``````````````````#<`@``$@`````````````````````````!````(```
M```````````````````````.`@``$@````````````````````````!L`0``
M$@`````````````````````````=````(`````````````````````````!*
M`@``$@````````````````````````"F`0``$@``````````````````````
M```W````$@````````````````````````"K`@``$@``````````````````
M``````#2`@``$0````````````````````````!4````%@``````````````
M```````````'`@``$@`````````````````````````^`0``$@``````````
M``````````````"R`@``$@`````````````````````````M`@``$@``````
M``````````````````!G````$@````````````````````````"'`@``$@``
M``````````````````````#$````$@````````````````````````!X````
M$@````````````````````````"-`0``$@````````````````````````"H
M````$@````````````````````````#:````$@``````````````````````
M``"``@``$@````````````````````````#R`0``$@``````````````````
M```````P`0``$@````````````````````````"?`0``$@``````````````
M``````````!J`@``$@````````````````````````!C`@``$0``````````
M``````````````#?````$@````````````````````````"V`0``$@``````
M``````````````````!)`@``$@````````````````````````!Q`@``(@``
M``````````````````````"3````$@`````````````````````````7`@``
M$@````````````````````````#9`0``$@````````````````````````".
M`@``$@````````````````````````!9`0``$@``````````````````````
M```[`@``$@````````````````````````"V`P``$@``````````````````
M``````"W````$0`````````````````````````?`@``$@``````````````
M```````````E`0``$@````````````````````````!%````$@``````````
M``````````````!1`@``$@````````````````````````"5`@``$@``````
M``````````````````#>`0``$@````````````````````````!W`0``$@``
M``````````````````````"O`0``$@````````````````````````"_`P``
M$@`,`$`W````````M@````````!1!```$@`,`$(P````````.`4```````!>
M`@``$@`,`)`>````````K`$````````V`P``$@`,`!@G````````#```````
M``!4`P``$@`,`'HU````````Q@$```````!W!```$@`,`"0G````````O`$`
M```````W!```$``6`%"P``````````````````!'`P``$@`,`.`H````````
M*`````````!J`P``$@`,`'@M````````6@````````#7`P``$0`-`$!.````
M````!``````````4!```$@`,`(1+````````Z@`````````O!```$@`,`"PF
M````````,@````````!,!```$``6`'BP``````````````````!E!```$@`,
M`%8O````````[`````````".!```$@`,`-(M````````4`````````#F`P``
M$``5``"P``````````````````".`P``$@`,``@I````````\@`````````"
M!```$`#Q_P"X``````````````````!>!```$``5`%"P````````````````
M``"$!```$0`5`$BP````````"``````````?!```$``5`%"P````````````
M``````#L`P``$@`,`#P@````````(@````````#S`P``$``5``"P````````
M``````````!#!```$@`,`"I+````````6@````````#H`P``(``5``"P````
M``````````````#+`P``$``6`'BP``````````````````"D`P``$@`,`#@O
M````````'@````````!X`P``$@`,`%XF````````N@````````":`P``$@`,
M`&Y,````````N`$```````"6!```$@`,`/HI````````?@,`````````7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`
M<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D
M9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!S
M=')T;VL`<W1R;&5N`')M9&ER`')E860`7U]M96UC<'E?8VAK`'-T<G-T<@!M
M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?
M7W-P<FEN=&9?8VAK`%]?;65M;6]V95]C:&L`7U]F<')I;G1F7V-H:P!L<W1A
M=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN
M86QI>F4`<W1R8VAR`&UE;6-M<`!M96US970`;W!E;F1I<@!G971U:60`86-C
M97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!S=')N8VUP`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`&QD+6QI;G5X+7)I<V-V-C0M;'`V
M-&0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E
M<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C
M7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%])3U]S=&1I;E]U
M<V5D`%]?9&%T85]S=&%R=`!?7T1!5$%?0D5'24Y?7P!?7V=L;V)A;%]P;VEN
M=&5R)`!S:&%?=7!D871E`%]?4T1!5$%?0D5'24Y?7P!X<U]I;FET`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`
M<&%R7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(W
M```````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,`
M`P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!``$``P`!
M``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!``$`
M!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``P`0`P``$````$````"TD98&
M```%`*,$```0````LY&6!@``!`"N!```$````(>1E@8```,`N00````````!
M``$`&@,``!``````````AY&6!@```@"Y!````````)"K`````````P``````
M``!>(````````)BK`````````P````````#R(````````*"K`````````P``
M``````"X(````````/BO`````````P````````"0'@````````"P````````
M`P``````````L````````!BP`````````P````````"@3P```````""P````
M`````P`````````(4@```````"BP`````````P`````````04@```````#"P
M`````````P`````````84@```````#BP`````````P`````````@4@``````
M`$BP`````````P`````````H4@```````*"O`````````@````(`````````
M`````*BO`````````@````P``````````````+"O`````````@````X`````
M`````````+BO`````````@```!D``````````````,"O`````````@```!P`
M`````````````,BO````````"P```"(``````````````-"O`````````@``
M`"0``````````````-BO`````````@```"<``````````````."O````````
M`@```#,``````````````.BO`````````@```#<``````````````/"O````
M`````@```#\``````````````,BM````````!0````,``````````````-"M
M````````!0````0``````````````-BM````````!0````4`````````````
M`."M````````!0````8``````````````.BM````````!0````<`````````
M`````/"M````````!0````@``````````````/BM````````!0````D`````
M``````````"N````````!0````H```````````````BN````````!0````L`
M`````````````!"N````````!0````T``````````````!BN````````!0``
M``\``````````````""N````````!0```!```````````````"BN````````
M!0```!$``````````````#"N````````!0```!(``````````````#BN````
M````!0```!,``````````````$"N````````!0```!0``````````````$BN
M````````!0```!4``````````````%"N````````!0```!8`````````````
M`%BN````````!0```!<``````````````&"N````````!0```!@`````````
M`````&BN````````!0```!H``````````````'"N````````!0```!L`````
M`````````'BN````````!0```!T``````````````("N````````!0```!X`
M`````````````(BN````````!0```!\``````````````)"N````````!0``
M`"```````````````)BN````````!0```",``````````````*"N````````
M!0```"4``````````````*BN````````!0```"8``````````````+"N````
M````!0```"@``````````````+BN````````!0```"D``````````````,"N
M````````!0```"H``````````````,BN````````!0```"L`````````````
M`-"N````````!0```"P``````````````-BN````````!0```"T`````````
M`````."N````````!0```"X``````````````.BN````````!0```"\`````
M`````````/"N````````!0```#```````````````/BN````````!0```#$`
M``````````````"O````````!0```#(```````````````BO````````!0``
M`#0``````````````!"O````````!0```#4``````````````!BO````````
M!0```#8``````````````""O````````!0```#@``````````````"BO````
M````!0```#D``````````````#"O````````!0```#H``````````````#BO
M````````!0```#L``````````````$"O````````!0```#P`````````````
M`$BO````````!0```#T``````````````%"O````````!0```#X`````````
M`````%BO````````!0```$```````````````&"O````````!0```$$`````
M`````````&BO````````!0```$(``````````````'"O````````!0```$,`
M`````````````'BO````````!0```$0``````````````("O````````!0``
M`$4``````````````(BO````````!0```$8``````````````)"O````````
M!0```$<`````````````````````````EY,``#,#PT$#OH,N$P-#_9."@RX3
M4Q,`@[*"`&<`#@`7G@```SZ.+6<##@`3````%YX```,^#BUG`PX`$P```!>>
M```#/HXL9P,.`!,````7G@```SX.+&<##@`3````%YX```,^CBMG`PX`$P``
M`!>>```#/@XK9P,.`!,````7G@```SZ.*F<##@`3````%YX```,^#BIG`PX`
M$P```!>>```#/HXI9P,.`!,````7G@```SX.*6<##@`3````%YX```,^CBAG
M`PX`$P```!>>```#/@XH9P,.`!,````7G@```SZ.)V<##@`3````%YX```,^
M#B=G`PX`$P```!>>```#/HXF9P,.`!,````7G@```SX.)F<##@`3````%YX`
M``,^CB5G`PX`$P```!>>```#/@XE9P,.`!,````7G@```SZ.)&<##@`3````
M%YX```,^#B1G`PX`$P```!>>```#/HXC9P,.`!,````7G@```SX.(V<##@`3
M````%YX```,^CB)G`PX`$P```!>>```#/@XB9P,.`!,````7G@```SZ.(6<#
M#@`3````%YX```,^#B%G`PX`$P```!>>```#/HX@9P,.`!,````7G@```SX.
M(&<##@`3````%YX```,^CA]G`PX`$P```!>>```#/@X?9P,.`!,````7G@``
M`SZ.'F<##@`3````%YX```,^#AYG`PX`$P```!>>```#/HX=9P,.`!,````7
MG@```SX.'6<##@`3````%YX```,^CAQG`PX`$P```!>>```#/@X<9P,.`!,`
M```7G@```SZ.&V<##@`3````%YX```,^#AMG`PX`$P```!>>```#/HX:9P,.
M`!,````7G@```SX.&F<##@`3````%YX```,^CAEG`PX`$P```!>>```#/@X9
M9P,.`!,````7G@```SZ.&&<##@`3````%YX```,^#AAG`PX`$P```!>>```#
M/HX79P,.`!,````7G@```SX.%V<##@`3````%YX```,^CA9G`PX`$P```!>>
M```#/@X69P,.`!,````7G@```SZ.%6<##@`3````%YX```,^#A5G`PX`$P``
M`!>>```#/HX49P,.`!,````7G@```SX.%&<##@`3````%YX```,^CA-G`PX`
M$P```!>>```#/@X39P,.`!,````7G@```SZ.$F<##@`3````%YX```,^#A)G
M`PX`$P```!>>```#/HX19P,.`!,````7G@```SX.$6<##@`3````'7&&[*+H
MRN"`$*;D3OQ2^*J'%YD```,YZ0\C.+3Z(S3$^I,%!/L3!H3Z$P7$^R,N]/J#
M-PD`(S3T_(%'[_!?]A>6```#-H8-LH47E0```S7E#^\@4'27EP``@[>G$(/'
M!P!CA0<.EY<``(.W)PV7E```DX2D%9*7F&.#*<3[@T>G2QN%20`.!9/G-P`C
M#?=*[_`?[(,U!/N#)\3[B.2888TIJH88X1<W```3!R<L&.47EP```S>'$!CI
M%S<``!,'9RL8[05'8USW#!N(-P!"AJ$%$4>(89,7-P"VEP4GB..A!>,9!_^;
M!P8`C@>(;+:7`4=.AI<%``"3A85D([`'`._P'[HUR8AL$PI$_._P7]JJB=*%
M%S4``!,%Q?CO`(`4)<&(;._PW[/O\)_+`S>$_(,W"0"YCP%'I>OF8$9DIF0&
M:4)Z3H7B>25A@H#O\%_&EY0``).$A`>(["'%[_!?SY>7``"#MX?]A68SAT<`
M&&,VER,'!YH!MXAL[_!_NF&WB&@!Q>\0P')IO]*%%S4``!,%Q>GO```-B.A!
MU>6WD4>IMP5%[_#?MN_PG^/O`"`"JH<7E0```S5E^X)E,``3<0'_@48!1PJ(
M[_"?W@*0EY$``).!(7J"@```%Y4``!,%9?Z7EP``DX?G_6.(IP"7EP``@[>G
M\Y'#@H>"@!>5```3!47\EY4``).%Q?N)C9/7-4#]D;Z5A869Q9>7``"#MV?Q
MD<."AX*`01$BX!>4```3!$3Y@T<$``;DA>.7EP``@[?'\9''%Y4```,UI?*"
ME^_PO_B%1R,`]`"B8`)D00&"@&F_77&BX(;D)OR`"%')7N27EP``@[?GZH.[
M!P!CA`L(3O12\%;L@T<%`"J*KHJJB1,'T`.]RV.&YP"#QQD`A0G]^[N)24&#
MM`L`M<!*^%KH7HD3"]`#3H;2A2:%[_`_G+.'-`$)Y8/'!P!C@F<#@S2)`"$)
M[?!">:)Y`GKB:D)KHFNF8`9D)H7B=&%A@H`S"7E!$UDY0(4)(Z`J`<Z4X;^!
M1,6WHFN!1.F_@4EIOZ)Y`GKB:J)K\;=Q<2+Q)NU*Z0`9!O47F0```SFIWI,%
MA/6#-PD`(SST_(%'JH3O\#^\%>&#)X3VO6819_6/8X7G`"EG8YKG`(E%)H7O
M\%^:$S45`!&@`44#-X3]@S<)`+F/`4>9YZIP"G3J9$II36&"@._P_\55<:+A
M4O&&Y8`)%YH```,Z"MB#-PH`(SST^H%'&<4F_8-'!0"JA)GOZG0#-X3[@S<*
M`+F/`4=CF@<,KF`.9`IZ:6&"@$KY3O7O\#^_*HE)S4J%[_"?D%G!@T8U`9,)
M-0&;AB;]@>:#QAD`_=(#1S4!&P<G_37/)H56[>_P'XRJBDZ%[_"?B[N*J@")
M*E:%[_#?B\Z')H>7-@``DX;&N5:&B46JB>_P?[63!83S3H7O\-^8_5=C"?4`
M@R>$]+UF$6?UCV.`YP1.A>_P/Y-.A>_PWZ)*A>IJ[_!?B#W]2H7O\-^6)H7O
M\'^/ZG1*>:IY-;\#QQD`&P<G_3W_`\<I`"G;G;].A>_PW^_1MR;]2OE.]5;M
M[_"?M%EQHO"F[,KHSN16_(;TTN!>]&+P@!B#QP4`EYD``(.YJ<4JB9.'-_R3
MMQ<`LX3U`":%@[<)`",\]/B!1^_PC_ZJBI,%1/E*A>_P']AYS2J*[_!/_6-Z
M50N#*T3Y%YP```,\C,*."P-'"0#*AY,&T`-C``<48P;7``/'%P"%!WW[NX<G
M00,Z#``3A2H`/I5>FN_P3_HC,*H`,<4#-PP`@T<)`!,%&0!>EQ1C$P;0`R.`
M]@"!ZXVH@T<%``4%HP#W`+W#-H>%!N.8Q_Z3!M`#DP<7`",`UP`#QP0`A0>%
M!*./Y_YU^P,WA/F#MPD`N8\!1^GGIG`&=.9D1FFF:09JXGJB>P)\96&"@(/'
M!``%"H4$HP_Z_N';@\<$``4*A02C#_K^_?/!MS:'3;=:^&;L:N@7G````SQ,
MM0,]#`"#-PT`M<OJAP%*F&?2AJ$'!2IE_XTF$YLV`)>7``"3AV>]F$,-[P5'
M6H68P^_PS^RJC#G)DQLZ`-J&7H;JA>_POX`C,)P!FP<:`(X'OIPCL`P`0GOB
M;$)M(RI$^?FUVH5JA>_P?XXC,*P`JHP1S9,;.@#1OX%'R;U!2P%*>;]:^&;L
M:NCO\%^80GOB;$)M*;]=<:+@)OQ*^$[T4O!6[(`(AN3]=_URDX>'^X5DEYD`
M`(.YR:@6D:J*+HH3AO3_LX6'`!<U```3!662@[<)`",\]/J!1^_P3^\;"04`
M8UT@`1,'!/RS!)=`FP?Y_[Z4`\>$_QWOC>^7EP``@[>GIE*&UH62EXAC[_`O
MY@,WA/N#MPD`N8\!1ZGGA6(6D:9@!F3B=$)YHGD">N)J86&"@#Z)_7>3AX?[
MLX2'`$J&DP7P`B:%[_!O^T79EY<``(.WAZ'*AB:&DI>(8]:%[_#O\W6W[_"?
MB@$1)N27E```@[2$GR+H!NP`$+.'1`"(8Y=V``"3AD:;%Y8```,V1IZ7-0``
MDX7%AN_P7X*2E$)DB&#B8*)D%S<``!,'9[Z!1[J&%Q8``!,&1O:7-0``DX4E
MA@5A;_"/ZD$1EY<``(.WIYDBY``((F22EXACEW8``).&AI47E@```S:&F)<U
M``"3A06!00%O\&_\'7&&[*+HIN2`$,K@3OQ2^%;T^7(7F@```SKJDA:1@S<*
M`",\]/J!1^_PK^#Y=Y.'A_JSA(<`!68JAY<W``"3AP>`ES8``).&!H`%!HE%
M)H7O\"_V_763AP7[,XF'`":%!6;*A>_P[]:;!`4`@4ECP00"FXH4`%:%[_"O
MR*J)"<DFAM:&RH7.E._PK_<C@`0``S>$^X,W"@"YCP%'B>^)8A:1YF!.A49D
MIF0&:>)Y0GJB>B5A@H#O\,_U01$BY``((F1!`36_$7&B^:;URO'.[6+Y``*&
M_=+IUN7:X5[]9O5J\6[M_7?]<I.'1_`7G````SQLA1:1*HFNB1<E```3!05V
MLX6'`(,W#``C-/3X@4?O\'^8JH23!?`"2H7O\&_:,<$7)0``$P6%=,J%[_`_
MNDJ%`S>$^(,W#`"YCP%'8Y`'%(5B%I'N<$YTKG0.>>YI3FJN:@YKZGM*?*I\
M"GWJ;1%A@H!.A>_PS]B7)0``DX4%<>_P#[,JC4W5_7E]>I.'B?BSB8<`DP>*
M\(5J,XJ'`),'!/FSC%=!@T<-`)<K``"3BVMN%RL``!,+:V[)RY'$ZH4FA>_P
M[\@UQ6J%[_!OLY,']?_JEZJ-DP;P`F-H_0`QJ".`!P#]%V,&_0`#QP<`XPG7
M_FJ%[_#/L*J-2H7O\$^P;I4%!>-V5?.)14J(WH=JA]J&!69.A>_PK]K2A4Z%
M[_`OO@'I@Z>,^+UF(6?UCV./YP*7)0``DX5E90%%[_!/IRJ-XP<%[H-'#0"M
M^Y'$@\<$`)N')_V9QX5-%RT``!,-;6!AOX/'%`#IU_VWA45.A>_P#ZU=_<Z%
M%R4``!,%!6#O\-^E3H7O\*_'7;WO\$_9`1$BZ";D!NP`$),%\`*JA._P#\D9
MP9,$%0!"9.)@)H6B9`5A;_#/Q#EQ(OA.[`;\)O1*\(``EXD``(.YJ6C]<H.W
M"0`C-/3\@4<6D5G)@T<%`"J)V<?O\*^A$P85`(5GJH1CZ,<*?7>3!X?\,X>'
M`,J%.H7O\,^RDX?T_ZJ7DP;P`F-H]0`1J".`!P#]%V.&IP`#QP<`XPG7_GUU
MDP>%_+.$AP"3!?`")H7O\&^_%<EC[J0$?763!X7\,X6'`._P+[L#-X3\@[<)
M`+F/`4>AYX5B%I'B<$)THG0">>)I(6&"@`,WA/R#MPD`N8\!1X7GA6(6D>)P
M0G2B=`)YXFD7)0``$P4E32%A;_"/MB,`!0!5MP%%?;?O\*_'.7$B^";T2O!.
M[%+H@``&_!>)```#.6E9@S<)`",T]/R!1Y,$1/R7*0``DXD)31>*```#.HI8
MIH5.A>_P#^P=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_PS^EY
M_9<I``"3B2E*%XH```,ZJE2FA4Z%[_`OZ!W!`R=$_(,W"@`.![J7F&>8XWW3
MF&NA!YCC;?^FA4Z%[_#OY7G]ERD``).)R487B@```SK*4*:%3H7O\$_D'<$#
M)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\`_B>?V7*0``DXGI0Q>*
M```#.NI,IH5.A>_P;^`=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.
MA>_P+]YY_9<I``"3B8E`%XH```,Z"DFFA4Z%[_"/W!W!`R=$_(,W"@`.![J7
MF&>8XWW3F&NA!YCC;?^FA4Z%[_!/VGG]ERD``).)J3T7B@```SHJ1::%3H7O
M\*_8'<$#)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\&_6>?V7*0``
MDXE),A>*```#.DI!IH5.A>_PS]0=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8
MXVW_IH5.A>_PC])Y_9<I``"3B>DV%XH```,Z:CVFA4Z%[_#OT!W!`R=$_(,W
M"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%[_"OSGG]ERD``).)"307B@```SJ*
M.::%3H7O\`_-'<$#)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\,_*
M>?V7*0``DXDI,1>*```#.JHUIH5.A>_P+\D=P0,G1/R#-PH`#@>ZEYAGF.-]
MTYAKH0>8XVW_IH5.A>_P[\9Y_9<I``"3B<DC%XH```,ZRC&FA4Z%[_!/Q1W!
M`R=$_(,W"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%[_`/PWG]IH47)0``$P5%
M*N_P#\*JA1G%%R4``!,%12?O\(_DIH47)0``$P7E*>_P+\"JA1G%%R4``!,%
M92KO\*_BIH47)0``$P6%*N_P3[ZJA1W-%R4``!,%!1KO\,_@`S>$_(,W"0"Y
MCP%'L>-"=.)PHG0">>)I0FJ7)0``DX6E*1<E```3!:4=(6%O\,_=IH47)0``
M$P6E)N_P;[FJA6'1%R4``!,%I1WO\._;3;_O\,^/>7$B\";L`!@&])>$``"#
MM.0ADP5$_1<E```3!24;G&`C//3\@4?O\&^U!<6#1P4``46)QY.'!_TS-?``
M`S>$_9Q@N8\!1X'KHG`"=.)D16&"@`%%Y;?O\"^*'7$BZ`;L`!`JCA>%```#
M-44@"&$3`X0`#.00Z!3L'/08\",X!`,C/!0#EX<``(.W1QJ:AG*&B4688R,T
MY/X!1R,P9/[OX+_<$P7P#^_@/]A9<:+PTN!6_&KHAO2F[,KHSN1:^%[T8O!F
M[(`8P7(7C0```ST-%H,W#0`C//3X@4<6D0E&@46JBN_@?^D3"O7_$U?Z0T&3
MLP?J`,(7P9.9CS,*^D!C00H*07E!;),'"?E]6S.)AP`A#)U,EXD``).)R1?!
M>P%&TH56A>_@7^5C!&4)8H;*A5:%[^!_\0$E8P9E!V/_K`1A%;,$J0!C]B0!
M@:C]%&/F)`4A1LZ%)H7OX!_?9?G!=Y.'!_FBES.%]$!2E0,WA/F#-PT`N8\!
M1['CP6(6D:9P!G3F9$9IIFD&:N)Z0GNB>P)\XFQ";65A@H!>FN,1>OE]5>FW
M%R4``!,%10WO\/_J%R4``!,%A0OO\#_J[^#?\T$1(N`&Y``([^`?P`$E[^"_
MZQ'!"&&B8`)D00&"@#EQ(OA*\$[L@``&_)>)``"#N>D#*HF3!43\%R4``!,%
M!0F#MPD`(S3T_(%'[_`OEPW))O2#1P4`JH2=P\J%[^#?QCG!`S>$_(.W"0"Y
MCP%'V>?B<$)THG0">>)I(6&"@*)T`S>$_(.W"0"YCP%'RH47)0``$P6E`[7G
M0G3B<`)YXFDA86_P+[5*A5+H[^#_MBJ*)H7OX'^V*IH)"E*%[^#?MB:(ER<`
M`).'Y^U*AY<F``"3AD;N4H:)1:J$[^#_WP,WA/R#MPD`N8\!1Y'KIH5":J)T
M%R4``!,%9?UYOU+H[^"_XR;T4NCOX#_C)7$BZTKC`!/._M+Z!N\FYY>'``"3
MAV?[@[@'`0.XAP&0<Y1WF'N<?Q>*```#.FKS`S,*`",\9/@!0Q<C```3`\/Y
M$PG$YR,\].R7)P``DX='^:J)(S!DZ",\].@7(P``$P,CX9<G``"3AR?XRH47
M)0``$P6%X",T9.@C.`3H(S@4ZR,\!.LC,,3L(S34[",XY.PC,/3J(S0$ZN_P
MCX$1Q8-'!0"JA&.0!R36]MKRWN[BZN;F[^"_I`$E[^!?T&,*!1B#.P4`8X8+
M&%Z%[^`_I),4%0"%!":%[^!_I`/'"P`JC*:,JHH-SQ<K```3"^OPVH8FAHE%
M8H7OX'_-A0OFAF/SG`"FAK.'ED")!V/SUP"VAP/'"P#Y%)6,OI0)#&G[$PL$
MZQ<E```3!:7C*:`#-8L`(0L-P<J%[^"_]ZJ$9=F#1P4`[=?O\"^"==$FA>_@
M'[RJA!7A$PL$Z(,T"P")S(/'!`!CA0<.)H7OX/__8>F#-(L`(0OM]":%[^!?
MF2J+5H7OX-^8.PNK`!L+2T!:A>_@_YB7)P``DX>GT-:(%R@``!,(".8FAY<F
M``"3AN;E6H:)1:J+[^"?P9,%`!Q>A>_@_[+]5V,8]0#OX%^7'$%%1V.:YPZ3
M!03N7H7OX#^WJH0!Z8,G!.^]9A%G]8]CB><*EX<``(.WQ]J#M@D`B&->AQ<F
M```3!D;EB47OX#^Z@4H#-X3Y@S<*`+F/`4=CD@<P^F!:9!9[]FM6;+9LNF0:
M:?9Y5GI6A;9Z'6&"@":%[^#_K*J$(0OC"07P-;>!1"6W`S6$Z9,$A.D9R<J%
M[^!?Y0'%@T<%`)7CB&2A!'WU-47OX-^**HRJBK5,M427*P``DXL+U1,',`6Y
MO>_@/ZBJBV'=[^"_AY,4%0"%!"6]@RJ$[^_@OX6;!P4`XY/Z](,G!._JXA,'
M`!R3]_<?8XCG!!9M/;<7AP```S>'S8.V"0`(8Q<F```3!B;47H>)1>_@_ZPU
MM^_P_\(#-X3Y@S<*`+F/`4=CF0<B6F3Z8!II]GE6>B:%NF0=86_@7Z!:A>_@
M_X#*A:J*%R4``!,%9=GOX#_9JH5C#040`[4)`._P3[NJC&,&!1!FA>_@3_T;
M#`4`C4=CV(<#$P7,_Y<E``"3A:769I7OX)^0">V11V,&_!B;![S_YI<#QP<`
MDP?P`F,-]Q;*A1<E```3!86X[^!?TW'!@T<%`-W/$P<``V.,YPJ7)0``DX5%
MP!<E```3!46V[^"?]._@GXHJB)<H``"3B"C@ER<``).'IZY>AY<F``"3AH;2
M6H:)15:%[^`_H'U9Q4D7+0``$PVMW9<L``"3C"RL%RP``!,,+-$EH._@#_4<
M06.7-P/OX'^%A20JB&K@IHCFAUZ'XH9:AHE%5H7OX/^;DP4`'%:%[^!?C>,(
M)?U>A>_@OXK6A1<E```3!<6D[^"?ZU:%[_#?K19MT;N#O`D`U;V!16:%[^!?
MGRJ)*='O\/^8JHGC307RDP5E_P%&2H7OX+^$$PP$]AE&XH5*A>_@WY"91V,?
M]0@#)P3VMT=!0Y.'!S#C%??P`U=,`)%GDX>'5.,>]^X!1I.%Z?Q*A>_@WX"3
M!(3V$P:``J:%2H7OX-^,DP>``F,>]027*```DX@(SR:(ER<``).'9YU>AY<F
M``"3AD;`6H:)15:%(P@$^._@OXXMOX.YB0#C@PGH3H7OX*_AC4?C_:?F<167
M)0``DX7ENTZ5[^!/]>,3!>;.C(6U%R4``!,%!;OO\#^'ZN+OX+^0UO;:\M[N
MXNKFYNKB[^"_CUUQ)OR7A```@[2DI*+@3O12\(;D2OA6[(`(LX=$``.Y!P`3
M"D3[EXD``(.Y":"#1PD+TH47)0``$P4EEP.W"0`C/.3Z`4>C"/D*[^`?LQG%
M`T<%`),'$`-C`?<4[_!/PK.'1``#N0<`2H6-1@5&ER4``).%A;;OX`_=*HD%
MQ1QI,X=$``ACC&,7)@``$P9FM>_@;]R#-PD!C&/<11.7EP)C2P<0LX=$`(AC
MC48%1I<E``"3A86S[^`/V2J)EXH``).**J(5P=*%%R4``!,%98COX+^J*H9Y
MQ8,W"0$SAT0`"&.,8^_@+]>SAT0``[D'``5&ER4``).%Q:]*A>_@K\JJA1<F
M```3!D:P2H7OX*_4DI2<8-*%%R4``!,%A8*CB`<*[^"?I2.XJ@"JA"G)DP4`
M'":%[^`OZ!L'%0"%1V/PYP+%1V,-]0"#MXH`JH8FAHQC%R4``!,%1:[OX,_L
M`S>$^X.W"0"YCP%'H>^F8`9DXG1">:)Y`GKB:F%A@H`#M8H`[_!_E".XJ@"J
MA$WQ%R4``!,%!:COX`_I@T<5`..%!^QMO0.WB@"#-PD!#&.(8^_@_]P5O[.'
M1`"(8^_@K^/5M>_@3_,Y<2+X)O1*\(``!OR7A```@[1$A2J)DP5$_!<5```3
M!65^G&`C-/3\@4?OX+^8"<V#1P4`D<L3!P`#8X?G`&,%"0"#1PD`B>\#-X3\
MG&"YCP%'N>_B<$)THG0">2%A@H!*A4[L[_!/EI,%\`*JB>_@+]T9P9,)%0!.
MA>_@;]D11I<E``"3A06([^"/M!G!XFEEOP,WA/R<8+F/`4>9ZT)TXFGB<*)T
M2H4">2%A;^"_HD[L[^#OYQ,!`=,C,($L(SR1*H`-(S01+",X(2LC-#$K(S!!
M*R,\42F7=```@[2$>),&A--!;OU>G&`C//3Z@4>3"(4#DP^%!S:(D]X.`C</
M_P`3#@[P`[8(`$$(H0B3508"$Q>&`9,3A@"35X8"DU*&`!-9A@,3DX4!,W?7
M`;/SXP&S]\<!,V=W`+/RP@&SYR<!,W/3`:(%,V=7`!M6A@&SYV<`L_7E`5&/
MS8\C..C^(SSX_N.1'_O]58,_!-H#/X3:`S<$VX,^A-0#/@35`S.$U8,X!-8#
M.(36@S,$UQ.)!B"!D1&@LH.P8IQBNH*A!K&/L\?W`;/'UP$3EQ<`_8-=CVV/
MN/[ZC_*.%H\:CD:#PH@>B..9)OT#.`4`@S^$TX,X!0$#/H4``S.%`8,^!0(W
MAH):$P:6F1-7N`&3%U@`V8^RGQ-?+@#MC_:?,\=H`),6[@&SYN8!_I<S=\<!
M@S\$U#/_M@`S1V<`NI<SQ^@![8\S=P<!LI^3DU<`$]FW`9J?,T<7`7Z7L^\C
M`9-9*`"3$N@!?I>#/X34L^(R`;/&5@#]CK*?;8^SQN8!QI^3D^<!B8.SX_,`
M$QE7`)-9MP&SA_8!@S\$U;-F.0&VE[/&<@"RG[/RL@#YCNV/?I^SQE8`$YE7
M`)/9MP&3'^<!^I8)@P,_A-6S[^\`,V<Y`;J6,\?S`>V.L_.S`'V/,I\6GQ.9
M5@"3V;8!,T=W`).2YP&)@[/B\@!ZE[-G.0$^ES-_MP`#-P36L\=?`/6/L_^_
M`#*7'I<3&5\`DUF_`;/']P&ZES-G.0&ZEY.3Y@&)@K/CTP"S]K<`@S>$UC/'
M<@`S=^<!L_*R`+*7_I<3F58`D]FV`3-'5P`^E[-G.0$^EY,?[P$37R\`L^_O
M`3-_MP`#-P37L\?S`?6/L_.S`#*7%I<3&5\`DUF_`;/'=P"ZES-G.0&ZEY.2
MY@&)@K/BT@"S]K<`@S>$US/'7P`S=^<!L_^_`+*7GI<3F58`D]FV`3-']P$^
ME[-G.0$^EY,3[P$37R\`L^/C`3-_MP`#-P38L\=R`/6/L_*R`#*7?I<3&5\`
MDUF_`;/'5P"ZES-G.0&ZEY.?Y@&)@K/OWP"S]K<`@S>$V#/'\P$S=^<!L_.S
M`+*7EI<3F58`D]FV`3-'=P`^E[-G.0$^EY,2[P$37R\`L^+B`3-_MP`#-P39
ML\=?`/6/L_^_`#*7'I<3&5\`DUF_`;/']P&ZES-G.0&ZEY.3Y@&)@K/CTP"S
M]K<`@S>$V3/'<@`S=^<!L_*R`+*7_I<3F58`D]FV`3-'5P`^E[-G.0$^EY,?
M[P$37R\`L^_O`3-_MP`#-P3:L\?S`?6/L_.S`#*7%I<3&5\`DUF_`;/'=P"Z
MES-G.0&ZEY.2Y@&)@K/BT@"S]K<`@S>$VC/'7P`S=^<!L_^_`+*7GI<3F58`
MD]FV`3-']P$^E[-G.0$^EY,3[P$37R\`L^/C`3-_MP`#-P3;L\=R`/6/L_*R
M`#*7?I<3&5\`DUF_`;/'5P"ZES-G.0&ZEY.?Y@&)@K/OWP"S]K<`@S>$VS/'
M\P$S=^<!LI>S\[,`EI>3$N\!$U\O`+/BX@$3F58`D]FV`0,_!-PS1W<`/I>S
M9SD!/I>SQU\`;8^S_[\`]8\RGQZ?$UFW`;/']P&3$U<`L^,C`?J7`SF$W!.?
MY@&)@C-OWP">E^V/L\;B`3*9L_*R`)/9MP'YCI.35P#*G[/&5@"SXS,!L_.S
M`/Z6GI:3'^<!@S,$W0F#L^_O`#/YM@`S1_\!LI,S?[\`DUFY`7V/$Q99`)Z2
M,T?G`3-F-@$6EVV.LP/'`).2YP$#-H3=B8.SXO(`-_?9;A,'%[JS^;,`L\=?
M`!/:N0&UCSJ6DY99`'J6[8^SYD8![8ZRES.&UP`3'^D!@S<$WA-9*0`S;R\!
ML\;B`3-YM@`S^K\`NI>SSW8`DU.Y`9,660"S_[\`TI>SYG8`_I?MCKZ6DY_I
M`8,WA-Z3V2D`L^\_`;/SM@"S2?\!,_JR`+J7L\+)`)/9LP$3EE,`L_*R`-*7
M,V8V`9:7;8X^EI,2Z0&#-P3?$UDI`+/B(@&SR5\`,WFV`#-ZOP"ZES//V0"3
M6;D!DQ99`#-_OP#2E[/F-@'ZE^V.OI83G^,!@S>$WY/3(P`S;W\`L\GB`;/S
MM@`S^K\`NI>SS\D`D]FS`1.64P"S_[\`TI<S9C8!_I=MCCZ6DQ_I`8,W!.`3
M62D`L^\O`;-)_P$S>;8`,_JR`+J7L\+9`)-9N0&3%ED`L_*R`-*7L^8V`9:7
M[8Z^EI.2XP&#-X3@D],C`+/B<@"SR5\`L_.V`#-ZOP"ZES//R0"3V;,!$Y93
M`#-_OP#2ES-F-@'ZEVV./I83'^D!@S<$X1-9*0`S;R\!L\GB`3-YM@`S^K\`
MNI>SS]D`DUFY`9,660"S_[\`TI>SYC8!_I?MCKZ6DY_C`8,WA.&3TR,`L^]_
M`+-)_P&S\[8`,_JR`+J7L\+)`)/9LP$3EE,`L_*R`-*7,V8V`9:7;8X^EI,2
MZ0&#-P3B$UDI`+/B(@&SR5\`,WFV`#-ZOP"ZES//V0"36;D!DQ99`#-_OP#2
ME[/F-@'ZE^V.OI83G^,!@S>$XI/3(P`S;W\`L\GB`;/SM@`S^K\`NI>SS\D`
MD]FS`1.64P"S_[\`TI<S9C8!_I=MCCZ6DQ_I`8,W!.,362D`L^\O`;-)_P$S
M>;8`,_JR`+J7L\+9`)-9N0&3%ED`L_*R`-*7L^8V`9:7[8Z^EI.2XP&#-X3C
MD],C`+/B<@"SR5\`L_.V`#-ZOP"ZES//R0"3V;,!$Y93`#-_OP#2ES-F-@'Z
MEVV./I83'^D!@S<$Y!-9*0`S;R\!L\GB`3-YM@`S^K\`NI>SS]D`DUFY`9,6
M60"S_[\`TI>SYC8!_I?MCKZ6DY_C`8,WA.23TR,`L^]_`+-)_P&S\[8`,_JR
M`+J7L\+)`)/9LP$3EE,`L_*R`-*7,V8V`9:7;8X^EI,2Z0&#-P3E$UDI`+/B
M(@&SR5\`,WFV`#-ZOP"ZES//V0"36;D!DQ99`#-_OP#2E[/F-@'ZE^V.OI83
MG^,!@S>$Y9/3(P`S;W\`L\GB`;/SM@`S^K\`NI>SS\D`D]FS`1.64P"S_[\`
MTI<S9C8!_I=MCCZ6DQ_I`8,W!.8362D`L^\O`;-YM@`S2?\!L_*R`!/:N0&Z
MES-)V0"3EED`,WFY`):7L^)&`1.:XP&3UB,`LV/:`,J7L_:R`+Z6@S>$YK/"
M?P`S^;8`,W^_`#/&P@"ZEY,260`36KD!^I<S?[8`^I<S[T(!^I<3END!`S\$
MYY/9*0`S9C8!L\G#`+/RMP"S_[\`L\?9`#J?$]JR`7Z?DYE2`+/_MP"SZ4D!
M?I].GY,6Z0$362D`L^8F`3?WQB,S>;8`_5>S=;\``S^$YX&3"@<3!\?-L__V
M`%6.LWGY`3J?,W96`+/S\P#ZDQ/:M0$S9C8!$Y_B`9.950"3TB(`,V]?`!Z6
ML^))`1:6@S($Z+-S_P"SYN8!?8ZS^7\`[8ZZDLJ2L^8V`1,95@"36;8!,VDY
M`9:6$YKE`<J6B8$#.83HLV6Z`+/R]0`S;[\`_8ZS^5,`,W_/`#J9,V\_`7Z9
MDYE6`!/:M@&3'^8!"8*S[\\`,P8O`3/O20%ZE@,_!.DS^?\`L^7U`7V.L_DB
M`3J?]8VSY34!^I.3&58`$UJV`1.?Y@&)@C-OWP"SAG4`L^5)`:Z6@S6$Z;-S
M_P"S[^\!_8ZS>7D`NI6S_\\`L^\_`:Z2DYE6`!/:M@&3%>8!"8+1C3.&7P"S
M[TD!?I:#/P3JL_+U`#-OOP!]CK/Y4P"ZGS-_WP`S;S\!?IF3&58`$UJV`9.?
MY@&)@K/OWP"S!B\!,^])`?J6`S^$ZC/Y_P"SY?4!_8ZS^2(!.I_QC;/E-0'Z
MDY.95@`3VK8!$Q_F`0F",V_/`#.&=0"SY4D!+I:#-03KLW/_`+/O[P%]CK-Y
M>0"ZE;/_WP"S[S\!KI*3&58`$UJV`9.5Y@&)@M6-LX9?`+/O20'^EH,_A.NS
M\O4`,V^_`/V.L_E3`+J?,W_/`#-O/P%^F9.95@`3VK8!DQ_F`0F"L^_/`#,&
M+P$S[TD!>I8#/P3L,_G_`+/E]0%]CK/Y(@$ZG_6-L^4U`?J3DQE6`!-:M@$3
MG^8!B8(S;]\`LX9U`+/E20&NEH,UA.RS<_\`L^_O`?V.LWEY`+J5L__/`+/O
M/P&NDI.95@`3VK8!DQ7F`0F"T8TSAE\`L^])`7Z6@S\$[;/R]0`S;[\`?8ZS
M^5,`NI\S?]\`,V\_`7Z9DQE6`!-:M@&3G^8!B8*S[]\`LP8O`3/O20'ZE@,_
MA.TS^?\`L^7U`?V.L_DB`3J?\8VSY34!^I.3F58`$]JV`1,?Y@$)@C-OSP`S
MAG4`L^5)`2Z6@S4$[K-S_P"S[^\!?8ZS>7D`NI6S_]\`L^\_`:Z2DQE6`!-:
MM@&3E>8!B8+5C;.&7P"S[TD!_I:#/X3NL_+U`#-OOP#]CK/Y4P`S?\\`NI_*
MGS-O/P$3F58`D]FV`3-I.0%^GTJ?,WG_`!,:Y@$#/P3O"8(S9LH`LW_V`-&-
ML_GR`?6-.I\>G[/E-0&3$UD`DUFY`1.:Y@'ZE8F",^\S`8,YA.^S9MH`L_/V
M`/J558XS__4`,W8F`;/U?P"ZF9:9$QI?`)-:OP%-CI-2*0"3%>D!3I8S:5H!
M2I8#.03PL^55`+/R]0#-CGV.L_E3`#J9L_;F`<J?L^8V`1,95@"36;8!_I:S
M;SD!_I:3&>\!@S^$\!-?+P"SZ>D!,_GY`+/E-0$S__8`L_HB`?&-NI^3%E\`
M$UJ_`9Z?L^55`;/C1@'^E9,6Y@&37R8`L^;V`;/S\P`SYMD`@SD$\9Z5L_/U
M`+/_]@"S>OD!$]JS`3-VY@&ZF1.74P"6F3-F5@&S8D<!3I:S\O(`LI*3&>\!
M`S:$\1-?+P`WMY@R,^_I`0H'$P=G';/&Y@&MCCJ62I;]CK/Y\@"REA.9XP$3
MUB,`LV/)`!/:N0&3E5D`,T9_`+/E10']C3-&5@"#,@3RMI4S^?4`NI(36KD!
MDQ99`):??8ZSYD8!_8Y^EC:6DY+I`8,VA/*3V2D`L^(R`;//4P"S>?8`,WK_
M`+J6,\^_`)/?N0&3E5D`,W__`-*6L^7U`?J6_8VVE1,?Z0&#-@3S$UDI`#-O
M+P&SS^(!,_GU`+/S\P`36KD!NI:SS\\`$Q99`+/__P">EC-F1@'^EGV.-I:3
MG^D!@S:$\Y/9*0"S[S\!LW/V`+-)_P$S^O(`NI:SPKD`D]FS`9.54P"S\O(`
MTI:SY34!EI;]C;:5DQ+I`8,V!/0362D`L^(B`;/)7P`S^?4`,WK_`+J6,\_)
M`)-9N0$3%ED`,W__`-*6,V8V`?J6?8XVEA.?XP&#-H3TD],C`#-O?P"SR>(!
MLW/V`#/Z_P"ZEK//N0"3V;,!DY53`+/__P#2EK/E-0'^EOV-MI63'^D!@S8$
M]1-9*0"S[R\!LTG_`3/Y]0`S^O(`NI:SPLD`DUFY`1,660"S\O(`TI8S9C8!
MEI9]CC:6DY+C`8,VA/63TR,`L^)R`+/)7P"S<_8`,WK_`+J6,\^Y`)/9LP&3
ME5,`,W__`-*6L^4U`?J6_8VVE1,?Z0&#-@3V$UDI`#-O+P&SR>(!,_GU`#/Z
M_P"ZEK//R0"36;D!$Q99`+/__P#2EC-F-@'^EGV.-I:3G^,!@S:$]I/3(P"S
M[W\`LTG_`;-S]@`S^O(`NI:SPKD`D]FS`9.54P"S\O(`TI:SY34!EI;]C;:5
MDQ+I`8,V!/<362D`L^(B`;/)7P`S^?4`,WK_`+J6,\_)`)-9N0$3%ED`,W__
M`-*6,V8V`?J6?8XVEA.?XP&#-H3WD],C`#-O?P"SR>(!LW/V`#/Z_P"ZEK//
MN0"3V;,!DY53`+/__P#2EK/E-0'^EOV-MI63'^D!@S8$^!-9*0"S[R\!LTG_
M`3/Y]0`S^O(`NI:SPLD`DUFY`1,660"S\O(`TI8S9C8!EI9]CC:6DY+C`8,V
MA/B3TR,`L^)R`+/)7P"S<_8`,WK_`+J6,\^Y`)/9LP&3E5,`,W__`-*6L^4U
M`?J6_8VVE1,?Z0&#-@3Y$UDI`#-O+P&SR>(!,_GU`#/Z_P"ZEK//R0"36;D!
M$Q99`+/__P#2EC-F-@'^EGV.-I:3G^,!@S:$^9/3(P"S[W\`LTG_`;-S]@`S
M^O(`NI:SPKD`D]FS`9.54P"S\O(`TI:SY34!EI;]C;:5DQ+I`8,V!/H362D`
ML^(B`;/Y]0`SR5\`,W__`!/:N0&ZEC-)R0`3EED`,WGY`/J6,V9&`<J6?8X3
MG^,!D],C`#-O?P"S@\8``S:$^K/&X@$S^?,`L___`#J6K8[]CI,560!^EA-:
MN0$VEK/F10$VEH,V!/N3G^D!D]DI`+/O/P$VE[-&_P&S=?8`0I>S\O(`L\9V
M`/V.$Y95`!/8M0$6ES:7LV8&`1,6Z0$362D`-I<S9B8!?8]&EO*5FI^S!M\!
M&.']C3-W]@`S]O\`]8\8Z1SQ#.40[0,WA/N<8+F/`4>5XX,P@2P#-`$L@S2!
M*P,Y`2N#.8$J`SH!*H,Z@2D3`0$M@H#OT*^T01$BX`;D``@3!0`([]"O@K=V
M74PW=^EAMR5%9Y.%%3"&!C=6,A`&!PSADX;FSY=%``"#M85%$P9F1Q,'!Q\,
MY13I$.T8\2,T!0(C.`4"(RP%!J)@`F1!`8*`.7$B^";T2O!.[%;D!OQ2Z%K@
M@``8=9,7-@`4>;J7@A>!DS.WYP`JB;J6*%T35]8!-I<C-/D"(SCI`K*)KH23
M"HD#.>V3!_`#8]\W"9N)"?P;VVD`&PH;`!H*)IJFA1,&``16A>_0CXF3A`0$
M2H7OX%_`XY5$_QL;:P"[B6E!3H;2A5:%[]"/AR,L.0?B<$)THG0">>)I0FJB
M:@)K(6&"@!,*``2[!ZI`/HIC3/8"&PL*`),*B0-:AJ:%5I7OT`^$@R>)!Q,'
M``2[!OH`(RS9!N.>YOI*A;N)24':E._@?[F5MS**Z;<FBEF_.7$B^";T2O!6
MY`;\3NQ2Z(```[J%`I.*A0.3!@#X$U8Z`!-V]@,SA\H`@[D%`Y,'%@`C`-<`
M$P>``ZZ$*HD%)F-8]Q(3!P`$$9^11C.%^@!C=M<4B4=C>O<28Q4'$B:%[^"?
MLA,&@`.!15:%[]!OCY/6"0$3UXD`D_;V#Z(&F]>)`1-W]P]"!]6/D_GY#^()
MV8\;5HH!DU8*`0(6L^<W`1-7B@"3]O8/HA;1CQ-W]P]"%]6/8AK9C[/G1P&\
M^":%[^"?K)Q@)H7A@R,`^0"<8,&#HP#Y`)Q@H8,C`?D`G&"C`?D`G&3A@R,"
M^0"<9,&#HP+Y`)QDH8,C`_D`G&2C`_D`G&CA@R,$^0"<:,&#HP3Y`)QHH8,C
M!?D`G&BC!?D`G&SA@R,&^0"<;,&#HP;Y`)QLH8,C!_D`G&RC!_D`G'#A@R,(
M^0"<<,&#HPCY`)QPH8,C"?D`G'"C"?D`0G3B<*)T`GGB:4)JHFHA86_`?_,3
M!X`#.P;'0(%%,X7Z`._`7_[]M2,`!0#9O2,`!0"C``4`>1<)!>,$!^SMMR,`
M!0"C``4`(P$%`*,!!0!Q%XE'$07C9/?JT;]!$2+D``@B9)=F``"#MB8=00%O
MP)_>``````$``@``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/
M5`````!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0
M``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E
M<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%
M4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%
M04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?
M1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!0
M05)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X``````````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D
M``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`````
M55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S
M:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M```E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````,```
M``````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,0```%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```````````M90```````"TM````````5$U01$E2``!414U01$E2
M`%1%35``````5$U0``````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,
M15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!
M4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T
M.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE0
M7TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI[
M"FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ
M*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O
M<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X]
M(#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I
M;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K
M("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R
M;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G
M+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B
M)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U
M:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U
M=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N
M9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<
M,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB
M*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#
M.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D
M(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U
M;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@
M1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&
M2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@
M=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@
M1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H
M97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD
M9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M
M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA
M;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@
M)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)
M3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@
M.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@
M("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q
M=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T
M86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!
M4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8[
M"B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE
M("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I
M;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*
M?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@
M97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("="
M)RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD
M<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z
M("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'
M5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M
M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@
M(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^
M.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K
M?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[
M)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L
M=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I
M='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO
M861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T
M<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F
M:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E
M;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B
M.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H
M)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A
M<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M
M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C
M:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E
M:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L
M(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB
M7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%2
M7TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T
M<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@
M86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO
M=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E
M<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O
M9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR
M96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S
M:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U
M9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*
M8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]
M("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L
M("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S
M92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D
M(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*
M<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N
M86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE
M('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P
M<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]
M("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD
M<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y
M<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B
M?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%
M3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T
M<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E
M='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`
M7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC
M('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS
M:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?
M87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL
M97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX
M<VDN8P``````````0T%#2$4``(FKS>\``````1L#.^P````<````V([__SP'
M``"$D/__!`$``#R1__\8`0``\I'__Y`!``!>DO__R`$``'23__\L`@``0)7_
M_Z`"```4EO__Y`(``'26__\0`P``II;__S0#``!@E___>`,``&R7__^<`P``
M*)G___@#``!0F?__)`0``$*:__]P!```P)W__[`$```:GO__X`0``&J>__\`
M!0``@)___U0%``">G___?`4``(J@___H!0``PJ7__YP&``"(I___X`8``#ZH
M__^`!P``<KO__\0'``#,N___[`<``+:\__\P"```;K[__W`(````````$```
M```````#>E(``7P!`1L-`@`0````&````'B/__\B``````<!`'0````L````
M')#__[8`````0@Y01H@$@0*)!D(,"`!,EQ)2DPJ4#)4.9I((EA!HTD+30M1"
MU4+60M="P4+(#`)01,E"#@!"#0B!`H@$B0:2"),*E`R5#I80EQ)2TM/4U=;7
M1)<20M=$DPJ4#)4.EQ)&TT+40M5"US0```"D````6I#__VP`````0@ZP`4:(
M!(D&D@A"#`@`0H$"`E(*P4+(#`*P`4+)0M)"#@!""P``8````-P```".D/__
M%@$```!"#M`!1H@$E`R!`D(,"`!:B09&R5+!0L@,`M`!0M1"#@!"#0B!`H@$
MB0:4#$22"),*<I4.`ES55`K)0M)"TT(+4I4.2,G2T]5(B0:2"),*E0X``'``
M``!``0``0)'__\P!````0@YP4H@$B0:2"),*E0Z!`I0,EQ*8%$(,"``"W@K!
M0L@,`G!"R4+20M-"U$+50M="V$(.`$(+<)80F1::&`)8"M9"V4+:1@M6UMG:
M1)80F1::&$;6V=I&EA"9%IH81M9"V4+:0````+0!``"8DO__U`````!"#E!,
MB`2)!I((DPJ4#)4.0@P(`%:!`@)F"@P"4$+!0LA"R4+20M-"U$+50@X`0@L`
M```H````^`$``"B3__]@`````$(.($*)!DR(!($"0@P(`&;(#`(@1,%"R5X.
M`"`````D`@``7)/__S(`````0@X02H@"0@P(`$+(#`(07@X``$````!(`@``
M:I/__[H`````0@Y@1H$"B`2)!D(,"`!*D@B3"I0,E0X"C@H,`F!"P43(0LE"
MTD+30M1"U4(.`$(+````(````(P"``#@D___#`````!"#A!"B`)"#`@`0L@,
M`A!"#@``6````+`"``#(D___O`$```!"#H`"2H@$B0:2"),*F!1"#`@`8H$"
ME`R5#I80EQ*9%IH8FQH"4`H,`H`"0L%"R$+)0M)"TT+40M5"UD+70MA"V4+:
M0MM"#@!""P`H````#`,``"B5__\H`````$(.($:(!(D&@0)"#`@`4L@,`B!"
MP43)0@X``$@````X`P``))7___(`````0@Y`2H@$DPJ!`HD&D@A"#`@``IX*
M#`)`0L%"R$+)0M)"TT(.`$(+4@H,`D!"P4+(0LE"TD+32@X`1`L\````A`,`
M`,J5__]^`P```$(.0$J(!(D&D@B3"I0,0@P(`$*!`@,J`PK(#`)`0L%"R4+2
M0M-"U%(.`$0+````+````,0#```(F?__6@````!"#C!$B`2)!D(,"`!"@0("
M0`K!0L@,`C!"R4(.`$(+'````/0#```RF?__4`````!"#F!$B!2!$D(,"$``
M``!0````%`0``&*9__\6`0```$(.<%B(!)0,E0Z:&($"B0:2"),*EA"7$I@4
MF19"#`@``K@*#`)P0L%"R$+)0M)"TT+40M5"UD+70MA"V4+:0@X`0@LD````
M:`0``"2:__\>`````$(.$$2(!($"0@P(`%#!0L@,`A!"#@``:````)`$```:
MFO__[`````!"#D!&B`22"),*0@P(`&*!`DR)!EP*P4+(#`)`0LE"TD+30@X`
M0@M"R5K(#`)`0L%"TD+30@X`1`T(@0*(!(D&D@B3"D0*E`P"1M1"R4H+0I0,
M1,G41(D&E`P`L````/P$``":FO__.`4```!"#J`#1(@$D@A"#`@`8),*E`R!
M`HD&`HR5#I80EQ*8%)D6`W`!"L%"R`P"H`-"UD+70MA"V4+)0M)"TT+41-5"
M#@!""P*`FAA&VF+5UM?8V5;(#`*@`T+!0M)"TT+41,E"#@!$#0B!`H@$B0:2
M"),*E`R5#I80EQ*8%)D6FA@#,`$*VD(+`^(`VD*:&$35UM?8V=I,E0Z6$)<2
MF!29%IH8````0````+`%```>G___Q@$```!"#E!"B094B`23"I0,@0*2")4.
M0@P(``-4`0K!0L@,`E!"R4+20M-"U$+50@X`0@L```!8````]`4``*"@__^V
M`````$(.0$:(!(D&D@A"#`@`8($";`K!0L@,`D!"R4+20@X`0@M$DPIL"M-"
M"T[(#`)`0M-"P4+)1-)"#@!$#0B!`H@$B0:2"$*3"@```$````!0!@``E(?_
M_ZP!````0@Y@1H$"B`22"$(,"`!&B0:3"I0,`RP!"L%"R`P"8$+)0M)"U$33
M0@X`0@L`````````0````)0&``"VH/__-!,```!$#M`%2(@$B09"#`@`5($"
MD@B3"I0,E0X#\!(*P43(#`+0!43)1-)$TT341-5$#@!""P`D````V`8``*:S
M__]:`````$(.$$2(!($"0@P(``),P4+(#`(00@X`0``````'``#8L___Z@``
M``!"#D!0B`2)!I((DPJ5#H$"E`R6$$(,"``">@K!0L@,`D!"R4+20M-"U$+5
M0M9"#@!""P`\````1`<``'ZT__^X`0```$(.0$Z(!(D&D@B5#H$"DPJ4#$(,
M"``#3`$*R`P"0$+!0LE"TD+30M1"U4(.`$0+(````(0'``#VM?__%@````!"
M#A!"B`)"#`@`0L@,`A!*#@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````!```````````#`````````0``````
M```0`P````````$`````````&@,````````@`````````)"K````````(0``
M```````(`````````!D`````````F*L````````;``````````@`````````
M&@````````"@JP```````!P`````````"`````````#U_O]O`````-@"````
M````!0````````!8#0````````8`````````R`,````````*`````````,0$
M````````"P`````````8`````````!4````````````````````#````````
M`+BM`````````@````````!P!0```````!0`````````!P`````````7````
M`````%@5````````!P````````!($P````````@`````````@`<````````)
M`````````!@`````````'@`````````(`````````/O__V\``````0``"```
M``#^__]O`````.@2````````____;P`````"`````````/#__V\`````'!(`
M``````#Y__]O``````L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````T!H```````#0&@```````-`:
M````````T!H```````#0&@```````-`:````````T!H```````#0&@``````
M`-`:````````T!H```````#0&@```````-`:````````T!H```````#0&@``
M`````-`:````````T!H```````#0&@```````-`:````````T!H```````#0
M&@```````-`:````````T!H```````#0&@```````-`:````````T!H`````
M``#0&@```````-`:````````T!H```````#0&@```````-`:````````T!H`
M``````#0&@```````-`:````````T!H```````#0&@```````-`:````````
MT!H```````#0&@```````-`:````````T!H```````#0&@```````-`:````
M````T!H```````#0&@```````-`:````````T!H```````#0&@```````-`:
M````````T!H```````#0&@```````-`:````````T!H```````#0&@``````
M`-`:````````T!H```````#0&@```````-`:````````T!H```````"HJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H56)U;G1U(#$S+C(N,"TR,W5B=6YT=3$I(#$S+C(N,`!!4@```')I
M<V-V``%(````!!`%<G8V-&DR<#%?;3)P,%]A,G`Q7V8R<#)?9#)P,E]C,G`P
M7WII8W-R,G`P7WII9F5N8V5I,G`P7WIM;75L,7`P```N<VAS=')T86(`+FEN
M=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+G!R96EN:71?87)R87D`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"YR
M:7-C=BYA='1R:6)U=&5S````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````<`(```````!P`@```````"$````````````````````!````````
M````````````$P````<````"`````````)0"````````E`(````````D````
M````````````````!````````````````````"8````'`````@````````"X
M`@```````+@"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````V`(```````#8`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````,@#````````
MR`,```````"0"0````````8````"````"``````````8`````````$8````#
M`````@````````!8#0```````%@-````````Q`0```````````````````$`
M``````````````````!.````____;P(`````````'!(````````<$@``````
M`,P`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````.@2````````Z!(```````!@``````````8````"````"```````````
M`````````&H````$`````@````````!($P```````$@3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````6!4`
M``````!8%0```````'`%````````!0```!0````(`````````!@`````````
M>0````$````&`````````-`:````````T!H```````#``P``````````````
M````$``````````0`````````'X````!````!@````````"0'@```````)`>
M````````K"\```````````````````0```````````````````"$`````0``
M``(`````````0$X```````!`3@```````'A!```````````````````(````
M````````````````C`````$````"`````````+B/````````N(\```````#L
M````````````````````!````````````````````)H````!`````@``````
M``"HD````````*B0````````J`<```````````````````@`````````````
M``````"D````$`````,`````````D*L```````"0FP````````@`````````
M```````````!``````````@`````````LP````X````#`````````)BK````
M````F)L````````(````````````````````"``````````(`````````+\`
M```/`````P````````"@JP```````*";````````"```````````````````
M``@`````````"`````````#+````!@````,`````````J*L```````"HFP``
M`````!`"````````!@`````````(`````````!``````````U`````$````#
M`````````+BM````````N)T```````!(`@``````````````````"```````
M```(`````````-D````!`````P``````````L`````````"@````````4```
M``````````````````@```````````````````#?````"`````,`````````
M4+````````!0H````````"@````````````````````(````````````````
M````Y`````$````P````````````````````4*`````````F````````````
M`````````0`````````!`````````.T````#``!P````````````````````
M`':@````````4P````````````````````$````````````````````!````
M`P````````````````````````#)H````````/\````````````````````!
/````````````````````
